@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -24,7 +24,7 @@
 #include <iconv.h>
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief auxiliary class to convert from one charset to another
+//! \brief Auxiliary class to convert from one charset to another
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 class Iconv
 {
@@ -35,7 +35,7 @@ public:
   Iconv& operator= (Iconv&&) = default;
   Iconv (const std::string&, const std::string&);
   ~Iconv ();
-  const mobius::bytearray conv (const mobius::bytearray&) const;
+  mobius::bytearray conv (const mobius::bytearray&) const;
 
 private:
   iconv_t cd_ = (iconv_t) -1;
@@ -43,19 +43,20 @@ private:
 };
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief constructor
+//! \brief Constructor
 //! \param f_charset from charset
 //! \param t_charset to charset
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 Iconv::Iconv (const std::string& f_charset, const std::string& t_charset)
 {
   cd_ = iconv_open (t_charset.c_str (), f_charset.c_str ());
+
   if (cd_ == (iconv_t) -1)
     throw std::invalid_argument (mobius::MOBIUS_EXCEPTION_POSIX);
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief destructor. Deallocate iconv structure
+//! \brief Destructor. Deallocate iconv structure
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 Iconv::~Iconv ()
 {
@@ -64,23 +65,31 @@ Iconv::~Iconv ()
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-//! \brief convert bytearray from one charset to another
-//! \param str input bytearray
-//! \return converted bytearray
-//! \todo simplify output bytearray creation
+//! \brief Convert bytearray from one charset to another
+//! \param str Input bytearray
+//! \return Converted bytearray
+//! \todo Simplify output bytearray creation
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-const mobius::bytearray
+mobius::bytearray
 Iconv::conv (const mobius::bytearray& str) const
 {
+  mobius::bytearray out;
   size_t insize = str.size ();
   size_t outsize = insize * 6;
 
   char *inbuf = (char *) str.data ();
-  std::unique_ptr<char[]> outbuf (new char[outsize]);
+  auto outbuf = std::make_unique<char[]> (outsize);
   char *p_out = outbuf.get ();
-  ::iconv (cd_, &inbuf, &insize, &p_out, &outsize);
+  
+  if (::iconv (cd_, &inbuf, &insize, &p_out, &outsize) != (size_t) -1)
+    {
+      // flush out partially converted input
+      iconv (cd_, nullptr, nullptr, &p_out, &outsize);
 
-  return mobius::bytearray (reinterpret_cast <const uint8_t *> (outbuf.get ()), p_out - outbuf.get ());
+      out = mobius::bytearray (reinterpret_cast <const uint8_t *> (outbuf.get ()), p_out - outbuf.get ());
+    }
+
+  return out;
 }
 
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -97,7 +106,7 @@ namespace mobius
 //! \param charset charset
 //! \return string encoded as UTF-8
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-const std::string
+std::string
 conv_charset_to_utf8 (const mobius::bytearray& data, const std::string& charset)
 {
   bytearray output = conv_charset (data, charset, "UTF-8");
@@ -117,12 +126,12 @@ conv_charset_to_utf8 (const mobius::bytearray& data, const std::string& charset)
 //! \param t_charset to charset
 //! \return new bytearray
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
-const mobius::bytearray
+mobius::bytearray
 conv_charset (const mobius::bytearray& data, const std::string& f_charset, const std::string& t_charset)
 {
   std::string key = f_charset + '|' + t_charset;
 
-  iconv_list_t::const_iterator iter = iconv_list.find (key);
+  auto iter = iconv_list.find (key);
 
   if (iter == iconv_list.end ())
     {
