@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -30,7 +30,7 @@
 //! \return true/false
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 bool
-PyMobius_Model_Application_Check (PyObject *pyobj)
+pymobius_model_application_check (PyObject *pyobj)
 {
   return PyObject_IsInstance (pyobj, (PyObject *) &model_application_t);
 }
@@ -41,7 +41,7 @@ PyMobius_Model_Application_Check (PyObject *pyobj)
 //! \return new application object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *
-PyMobius_Model_Application_from_cpp (mobius::model::application obj)
+pymobius_model_application_to_pyobject (mobius::model::application obj)
 {
   PyObject *ret = nullptr;
 
@@ -64,7 +64,7 @@ PyMobius_Model_Application_from_cpp (mobius::model::application obj)
 //! \return new application object
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 mobius::model::application
-PyMobius_Model_Application_as_cpp (PyObject *pyobj)
+pymobius_model_application_from_pyobject (PyObject *pyobj)
 {
   return * (reinterpret_cast <model_application_o *>(pyobj)->obj);
 }  
@@ -81,7 +81,7 @@ tp_getter_case (model_application_o *self)
 
   try
     {
-      ret = PyMobius_Model_Case_from_cpp (self->obj->get_case ());
+      ret = pymobius_model_case_to_pyobject (self->obj->get_case ());
     }
   catch (const std::exception& e)
     {
