@@ -1,6 +1,6 @@
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 // Mobius Forensic Toolkit
-// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+// Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 //
 // This program is free software; you can redistribute it and/or modify it
 // under the terms of the GNU General Public License as published by the
@@ -31,7 +31,7 @@
 //! \return new registry_data object or None if object is null
 // =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 PyObject *
-PyMobius_OS_Win_Registry_Registry_Data_from_cpp (mobius::os::win::registry::registry_data r)
+pymobius_os_win_registry_registry_data_to_pyobject (mobius::os::win::registry::registry_data r)
 {
   PyObject *ret = nullptr;
 
@@ -43,10 +43,7 @@ PyMobius_OS_Win_Registry_Registry_Data_from_cpp (mobius::os::win::registry::regi
         ((os_win_registry_registry_data_o *) ret)->obj = new mobius::os::win::registry::registry_data (r);
     }
   else
-    {
-      Py_INCREF (Py_None);
-      ret = Py_None;
-    }
+    ret = mobius::py::pynone ();
 
   return ret;
 }
@@ -71,7 +68,7 @@ tp_getter_size (os_win_registry_registry_data_o *self)
 
   try
     {
-      ret = PyLong_FromUnsignedLong (self->obj->get_size ());
+      ret = mobius::py::pylong_from_std_uint32_t (self->obj->get_size ());
     }
   catch (const std::exception& e)
     {
@@ -91,7 +88,7 @@ tp_getter_type (os_win_registry_registry_data_o *self)
 
   try
     {
-      ret = PyLong_FromLong (int (self->obj->get_type ()));
+      ret = mobius::py::pylong_from_int (static_cast <int> (self->obj->get_type ()));
     }
   catch (const std::exception& e)
     {
@@ -161,7 +158,7 @@ tp_f_get_data_as_dword (os_win_registry_registry_data_o *self, PyObject *)
 
   try
     {
-      ret = PyLong_FromUnsignedLong (self->obj->get_data_as_dword ());
+      ret = mobius::py::pylong_from_std_uint32_t (self->obj->get_data_as_dword ());
     }
   catch (const std::exception& e)
     {
@@ -200,13 +197,20 @@ tp_f_get_data_as_qword (os_win_registry_registry_data_o *self, PyObject *)
 static PyObject *
 tp_f_get_data_as_string (os_win_registry_registry_data_o *self, PyObject *args)
 {
-  // parse input args
-  const char * arg_encoding;
+  // Parse input args
+  std::string arg_encoding;
 
-  if (!PyArg_ParseTuple (args, "s", &arg_encoding))
-    return nullptr;
+  try
+    {
+      arg_encoding = mobius::py::get_arg_as_std_string (args, 0);
+    }
+  catch (const std::exception& e)
+    {
+      PyErr_SetString (PyExc_TypeError, e.what ());
+      return nullptr;
+    }
 
-  // execute C++ function
+  // execute C++ code
   PyObject *ret = nullptr;
 
   try
@@ -218,7 +222,6 @@ tp_f_get_data_as_string (os_win_registry_registry_data_o *self, PyObject *args)
       PyErr_SetString (PyExc_Exception, e.what ());
     }
 
-  // return value
   return ret;
 }
 
