@@ -1,6 +1,6 @@
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # Mobius Forensic Toolkit
-# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020 Eduardo Aguiar
+# Copyright (C) 2008,2009,2010,2011,2012,2013,2014,2015,2016,2017,2018,2019,2020,2021,2022 Eduardo Aguiar
 #
 # This program is free software; you can redistribute it and/or modify it
 # under the terms of the GNU General Public License as published by the
@@ -22,6 +22,7 @@ import glob
 import os
 import os.path
 import traceback
+import shutil
 
 # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
 # @brief Resource list
@@ -110,6 +111,10 @@ class Application (object):
 
     # configure user account
     self.__configure_user ()
+    self.__install_cpp_extensions ()
+
+    app = mobius.core.application ()
+    app.start ()
 
     # start extensions API
     pymobius.mediator.call ('extension.start-all')
@@ -122,6 +127,8 @@ class Application (object):
     pymobius.mediator.emit ('app.stopping')
     pymobius.mediator.call ('extension.stop-all')
 
+    app.stop ()
+
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief Configure application for current user
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
@@ -133,9 +140,42 @@ class Application (object):
       os.makedirs (extensions_dir)
       dist_dir = app.get_data_path ('extensions')
 
+      # install Python extensions
       for path in sorted (glob.glob ('%s/*.mobius' % dist_dir)):
         print 'Installing extension %s' % os.path.basename (path)
         pymobius.extension.install (path)
+       
+  # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  # @brief Install C++ extensions
+  # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
+  def __install_cpp_extensions (self):
+    app = mobius.core.application ()
+    dist_dir = app.get_data_path ('extensions')
+    install_dir = app.get_config_path ('extensions')
+
+    for dist_path in sorted (glob.glob ('%s/*.so' % dist_dir)):
+      filename = os.path.basename (dist_path)
+      install_path = os.path.join (install_dir, filename)
+      can_install = False
+
+      # compare installed version and distribution version
+      if os.path.exists (install_path):
+        ext_dist = mobius.core.extension (dist_path)
+        ext_install = mobius.core.extension (install_path)
+
+        if ext_dist.version != ext_install.version:
+          can_install = True
+
+      else:
+        can_install = True
+
+      # install, if necessary
+      if can_install:
+        print 'Installing C++ extension %s' % filename
+        shutil.copy (dist_path, install_path)
+
+        ext = mobius.core.extension (install_path)
+        ext.install ()
 
   # =-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=-=
   # @brief service: app.add-resource
